@@ -31,6 +31,7 @@ from fireworks.utilities.fw_serializers import FWSerializable, \
     recursive_serialize, recursive_deserialize, serialize_fw
 from fireworks.utilities.fw_utilities import get_my_host, get_my_ip, \
     NestedClassGetter
+from fireworks.utilities.timing import get_fw_timer
 
 
 __author__ = "Anubhav Jain"
@@ -76,8 +77,20 @@ class FireTaskBase(defaultdict, FWSerializable):
         FireWork spec, perform some task using that data, and then return an
         output in the form of a FWAction.
 
-        :param fw_spec: (dict) a FireWork spec
-        :return: (FWAction)
+        Args:
+            fw_spec (dict): A FireWork spec. This comes from the master spec.
+                In addition, this spec contains a special "_fw_env" key that
+                contains the env settings of the FWorker calling this method.
+                This provides for abstracting out certain commands or
+                settings. For example, "foo" may be named "foo1" in resource
+                1 and "foo2" in resource 2. The FWorker env can specify {
+                "foo": "foo1"}, which maps an abstract variable "foo" to the
+                relevant "foo1" or "foo2". You can then write a task that
+                uses fw_spec["_fw_env"]["foo"] that will work across all
+                these multiple resources.
+
+        Returns:
+            (FWAction)
         """
         pass
 
@@ -325,6 +338,7 @@ class Launch(FWSerializable, object):
     A Launch encapsulates data about a specific run of a FireWork on a
     computing resource
     """
+    _tm = get_fw_timer("Launch")
 
     def __init__(self, state, launch_dir, fworker=None, host=None, ip=None,
                  trackers=None, action=None, state_history=None,
@@ -350,8 +364,10 @@ class Launch(FWSerializable, object):
 
         self.launch_dir = launch_dir
         self.fworker = fworker or FWorker()
+        self._tm.start("get_addr")
         self.host = host or get_my_host()
         self.ip = ip or get_my_ip()
+        self._tm.stop("get_addr")
         self.trackers = trackers if trackers else []
         self.action = action if action else None
         self.state_history = state_history if state_history else []
